@@ -1,5 +1,5 @@
 package ExtUtils::Builder;
-$ExtUtils::Builder::VERSION = '0.001';
+$ExtUtils::Builder::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -19,7 +19,7 @@ ExtUtils::Builder - An overview of the foundations of the ExtUtils::Builder Plan
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -165,7 +165,7 @@ Writing extensions for various build tools can be a daunting task. This module t
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
