@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Action;
-$ExtUtils::Builder::Action::VERSION = '0.001';
+$ExtUtils::Builder::Action::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -39,7 +39,7 @@ ExtUtils::Builder::Action - The ExtUtils::Builder Action role
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ This action returns all actions behind this action. It may return itself, it may
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
