@@ -1,11 +1,12 @@
 package ExtUtils::Builder::Action::Code;
-$ExtUtils::Builder::Action::Code::VERSION = '0.001';
+$ExtUtils::Builder::Action::Code::VERSION = '0.002';
 use strict;
 use warnings;
 
 use parent 'ExtUtils::Builder::Action::Perl';
 
 use Carp ();
+use ExtUtils::Builder::Util 'get_perl';
 
 sub new {
 	my ($class, %args) = @_;
@@ -40,7 +41,7 @@ sub to_code {
 sub to_command {
 	my ($self, %opts) = @_;
 	my @modules = map { "-M$_" } $self->modules;
-	return [ $self->_get_perl(%opts), @modules, '-e', $self->to_code(skip_loading => 'main') ];
+	return [ get_perl(%opts), @modules, '-e', $self->to_code(skip_loading => 'main') ];
 }
 
 1;
@@ -59,7 +60,7 @@ ExtUtils::Builder::Action::Code - Action objects for perl code
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -91,7 +92,7 @@ modules
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
