@@ -1,13 +1,10 @@
 package ExtUtils::Builder::Action::Perl;
-$ExtUtils::Builder::Action::Perl::VERSION = '0.001';
+$ExtUtils::Builder::Action::Perl::VERSION = '0.002';
 use strict;
 use warnings;
 
 use parent 'ExtUtils::Builder::Action::Primitive';
 
-use Config;
-use Scalar::Util 'tainted';
-
 sub _preference_map {
 	return {
 		execute => 3,
@@ -22,20 +19,6 @@ sub message {
 	return $self->{message};
 }
 
-sub _get_perl {
-	my ($self, %opts) = @_;
-	return $opts{perl} if $opts{perl};
-	if ($Config{userelocatableinc}) {
-		require Devel::FindPerl;
-		return Devel::FindPerl::find_perl_interpreter($opts{config});
-	}
-	else {
-		require File::Spec;
-		return $^X if File::Spec->file_name_is_absolute($^X) and not tainted($^X);
-		return defined $opts{config} ? $opts{config}->get('perlpath') : $Config{perlpath};
-	}
-}
-
 sub to_code_hash {
 	my ($self, %opts) = @_;
 	my %result = (
@@ -62,7 +45,7 @@ ExtUtils::Builder::Action::Perl - A base-role for Code actions
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -86,7 +69,7 @@ preference
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
