@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Action::Primitive;
-$ExtUtils::Builder::Action::Primitive::VERSION = '0.001';
+$ExtUtils::Builder::Action::Primitive::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -26,7 +26,7 @@ ExtUtils::Builder::Action::Primitive - A base role for primitive action classes
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -40,7 +40,7 @@ This is an identity operator (it returns C<$self>).
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
