@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Node;
-$ExtUtils::Builder::Node::VERSION = '0.001';
+$ExtUtils::Builder::Node::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -56,7 +56,7 @@ ExtUtils::Builder::Node - An ExtUtils::Builder Node
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ to_code
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
