@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Planner;
-$ExtUtils::Builder::Planner::VERSION = '0.001';
+$ExtUtils::Builder::Planner::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -9,6 +9,7 @@ use List::Util ();
 
 use ExtUtils::Builder::Plan;
 use ExtUtils::Builder::Node;
+use ExtUtils::Builder::Util;
 
 my $class_counter = 0;
 
@@ -77,16 +78,9 @@ sub add_delegate {
 	return;
 }
 
-sub _require_module {
-	my $module = shift;
-	(my $filename = "$module.pm") =~ s{::}{/}g;
-	require $filename;
-	return $module;
-}
-
 sub load_module {
 	my ($self, $plannable, %options) = @_;
-	_require_module($plannable);
+	ExtUtils::Builder::Util::require_module($plannable);
 	return $plannable->add_methods($self, %options);
 }
 
@@ -162,7 +156,7 @@ ExtUtils::Builder::Planner - An ExtUtils::Builder Plan builder
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -257,7 +251,7 @@ This returns a new L<ExtUtils::Builder::Plan|ExtUtils::Builder::Plan> object bas
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
