@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Planner::Extension;
-$ExtUtils::Builder::Planner::Extension::VERSION = '0.001';
+$ExtUtils::Builder::Planner::Extension::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -40,7 +40,7 @@ ExtUtils::Builder::Planner::Extension - a base class for Planner extensions
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 METHODS
 
@@ -54,7 +54,7 @@ This adds a helper function to C<$planner> with name <$as>. It will return whate
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
